@@ -1,27 +1,27 @@
 # -*- perl -*-
+
 #
 # Author: Gisbert W. Selke, TapirSoft Selke & Selke GbR.
 #
-# Copyright (C) 2015, 2025 Gisbert W. Selke. All rights reserved.
+# Copyright (C) 2015 Gisbert W. Selke. All rights reserved.
 # This package is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 #
 # Mail: gws@cpan.org
 #
 
+
 package Map::Tube::Lyon;
-use 5.14.0;
-use version 0.77 ( );
 use strict;
 use warnings;
 
-our $VERSION = version->declare('v0.62.4');
+our $VERSION = '0.01';
 
 =encoding utf8
 
 =head1 NAME
 
-Map::Tube::Lyon - Interface to the Lyon metro, funicular and tramway map
+Map::Tube::Lyon - Interface to the Lyon métro map
 
 =cut
 
@@ -44,9 +44,8 @@ with 'Map::Tube';
 
 =head1 DESCRIPTION
 
-This module allows to find the shortest route between any two given
-stations in Lyon. Metro, funiculars and tramways are covered.
-All interesting methods are provided by the role L<Map::Tube>.
+This module allows to find the shortest route between any two given métro
+stations in Lyon. All interesting methods are provided by the role L<Map::Tube>.
 
 =head1 METHODS
 
@@ -55,15 +54,8 @@ All interesting methods are provided by the role L<Map::Tube>.
     use Map::Tube::Lyon;
     my $tube = Map::Tube::Lyon->new();
 
-The only argument, C<xml>, is optional; if specified, it should be a code ref
-to a function that returns either the path the XML map file, or a string
-containing this XML content. The default is the path to F<lyon-map.xml>
-that is a part of this distribution. For further information see L<Map::Tube>.
-
-=head2 xml()
-
-This read-only accessor returns whatever was specified as the XML source at
-construction.
+This will read the tube information from the shared file F<lyon-map.xml>,
+which is part of the distribution.
 
 =head1 ERRORS
 
